/*
 * Copyright (C) 2013, 2014, 2015
 *      Andrew Hayzen <ahayzen@gmail.com>
 *      Daniel Holm <d.holmen@gmail.com>
 *      Victor Thompson <victor.thompson@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.3
import Ubuntu.Components 1.1


// generic page for music, could be useful for bottomedge implementation
Page {
    id: thisPage
    anchors {
        bottomMargin: musicToolbar.visible ? musicToolbar.height : 0
        fill: parent
    }
    flickable: pageFlickable

    default property alias content: pageChildrenContainer.data
    property Flickable pageFlickable
    property bool searchable: false
    property int searchResultsCount

    onVisibleChanged: {
        if (visible) {
            onPageVisible()
        }
    }

    function onPageVisible() {
        mainPageStack.setPage(thisPage);

        // Rebind sidebar so that it is visible on this page
        nowPlayingSidebarLoader.parent = parent
        nowPlayingSidebarLoader.anchors.bottom = parent.bottom
        nowPlayingSidebarLoader.anchors.right = parent.right
        nowPlayingSidebarLoader.anchors.top = parent.top
        nowPlayingSidebarLoader.anchors.topMargin = Qt.binding(function() { return thisPage.header.y + thisPage.header.height; })
    }

    Label {
        anchors {
            centerIn: pageChildrenContainer
        }
        text: i18n.tr("No items found")
        visible: parent.state === "search" && searchResultsCount === 0
    }

    // FIXME: hack is a workaround for SDK bug pad.lv/1341814
    // which causes the header and contents of the page to become out of sync
    property Item __oldContents: null

    Connections {
        target: thisPage.head
        onContentsChanged: {
            if (thisPage.__oldContents) {
                thisPage.__oldContents.parent = null;
            }
            thisPage.__oldContents = thisPage.head.contents;
        }
    }

    Item {
        id: pageChildrenContainer
        anchors {
            bottom: parent.bottom
            left: parent.left
            top: parent.top
        }
        width: parent.width - (wideAspect ? nowPlayingSidebarLoader.width : 0)
    }

    Rectangle {  // Fill the header to stop the page appearing behind when scrolling
        anchors {
            left: parent.left
            right: parent.right
        }
        color: mainView.headerColor
        height: thisPage.header.height
        visible: wideAspect
        y: thisPage.header.y
    }

    Component.onCompleted: {
        if (visible) {  // onVisible is not sometimes called so use onComplete as well
            onPageVisible()
        }
    }
}
